@@ -1041,7 +1041,8 @@ static int receive_midi(gpointer data) {
 			}
 			else {
 				printf("note-on received late and not passed to sampler\n");
-				printf("diff: %llu, threshold: %d\n", (clock-timestamp)/1000000, JAMMING_LATETHRESHOLD/1000000);
+				printf("diff: %" G_GUINT64_FORMAT ", threshold: %d\n", (clock-timestamp)/1000000,
+					JAMMING_LATETHRESHOLD/1000000); 
 			}
 			// all note-on events are stored because jamming needs to be saved
 			jammomidi_store_event_to_glist(&(collaboration_jamming->priv->peer_event_list), buffer[JAMMING_NOTE], buffer[JAMMING_TYPE], timestamp);
@@ -1066,7 +1067,7 @@ static int receive_midi(gpointer data) {
 		// stop receiving if too long delay 
 		if (clock > 0 && clock - (collaboration_jamming->priv->time_of_last_received_event) >JAMMING_DELAYQUIT) {
 			printf("delayquit reached\n");
-			printf("clock: %llu, last event:%llu\n", clock, collaboration_jamming->priv->time_of_last_received_event);
+			printf("clock: %" G_GUINT64_FORMAT ", last event:%" G_GUINT64_FORMAT "\n", clock, collaboration_jamming->priv->time_of_last_received_event);
 			handle_communication_error(collaboration_jamming);
 			return 1;
 		}
@@ -1140,7 +1141,7 @@ int create_mix_of_jamming(gpointer data) {
 		// change sequencer to file mode
 		gchar * mix_location;
 		g_object_get(collaboration_jamming, "mix-location", &mix_location, NULL);
-		if (jammo_sequencer_file_mode(sequencer, mix_location)==0) {
+		if (jammo_sequencer_set_output_filename(sequencer, mix_location)) {
 			printf("sequencer changed to file mode successfully\n");
 		}
 
@@ -1152,7 +1153,7 @@ int create_mix_of_jamming(gpointer data) {
 	if (collaboration_jamming->priv->jamming_state==JAMMINGSTATE_GENERATING_MIX) {
 		JammoSequencer * sequencer;
 		g_object_get(collaboration_jamming, "sequencer", &sequencer,NULL);
-		printf("generating mix, position: %llu\n", jammo_sequencer_get_position(sequencer));
+		printf("generating mix, position: %" G_GUINT64_FORMAT "\n", jammo_sequencer_get_position(sequencer));
 		return 1;
 	}
 	else if (collaboration_jamming->priv->jamming_state==JAMMINGSTATE_DONE_GENERATING){
@@ -1184,7 +1185,7 @@ int store_jamming_data(JammoCollaborationJamming * collaboration_jamming) {
 	}
 
 	printf("finished jamming, saving jamming\n");
-	printf("time of last event: %llu\n", collaboration_jamming->priv->time_of_last_received_event);
+	printf("time of last event: %" G_GUINT64_FORMAT "\n", collaboration_jamming->priv->time_of_last_received_event);
 	jammo_sequencer_stop(sequencer);
 
 	// store own midi events to a file
